@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use version;
-our $VERSION = qv('0.16');
+our $VERSION = qv('0.17');
 
 use IPC::Open2;
 use Data::Dumper;
@@ -198,12 +198,12 @@ sub parse_completion_request {
     my $left = substr($comp_line,0,$comp_point);
     my @left = _line_to_argv($left);
 
-    # TODO: does this ever fire?
-    if (@left and my $delegate = $self->completion_handler('>' . $left[0])) {
-        # the first word matches a sub-command for this command
-        # delegate to the options object for that sub-command, which
-        # may happen recursively
-        return $delegate->parse_completion_request(@_);
+    # find options for last sub-command if it has a completion handler
+    # skipping first command but old code didn't but it also never seemed to trigger before
+    my @sub_cmds = @left[1..$#left];
+    while (@sub_cmds and my $delegate = $self->completion_handler('>' . $sub_cmds[0])) {
+        shift @sub_cmds;
+        $self = $delegate;
     }
 
     my $right = substr($comp_line,$comp_point);
@@ -224,7 +224,7 @@ sub parse_completion_request {
         $current = '';
     }
     $left =~ s/\\ / /g;
-    my $previous = ( (@left and $left[-1] =~ /^--/ and not $left[-1] =~ /^--[\w\-]+\=/) ? (pop @left) : ()) ;
+    my $previous = ( (@left and $left[-1] =~ /^-{1,2}/ and not $left[-1] =~ /^-{1,2}[\w\-]+\=/) ? (pop @left) : ()) ;
     # TODO: this might be a good spot to make sure we don't complete a new sub-command
     my @other_options = (@left,@right);
 
@@ -269,7 +269,7 @@ Getopt::Complete::Options - a command-line options specification
 
 =head1 VERSION
 
-This document describes Getopt::Complete v0.16.
+This document describes Getopt::Complete 0.17.
 
 =head1 SYNOPSIS
 
